//
//  YHCertificateResourceUploadVC.swift
//  galaxy
//
//  Created by edy on 2024/3/13.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import JXSegmentedView
import UniformTypeIdentifiers
import IQKeyboardManagerSwift
import SwifterSwift

class YHCertificateResourceUploadVC: YHBaseViewController {

    var orderId : Int?
    var status: YHCertificateUploadStatus = .all
    var items:[YHSupplementInfo] = []
    var viewModel: YHCertificateViewModel = YHCertificateViewModel()
    var categoryInfo: YHCategoryData!

    lazy var tableView: UITableView = {
        
        let tableView = UITableView(frame:.zero, style:.grouped)

        if #available(iOS 11.0, *) {
            tableView.contentInsetAdjustmentBehavior = .never
        }
        tableView.estimatedSectionHeaderHeight = 14.0
        tableView.estimatedSectionFooterHeight = 1.0
        tableView.showsVerticalScrollIndicator = false
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.backgroundColor = UIColor(hexString:"#F8F8F8")
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "UITableViewCell")
        tableView.register(YHCertificateInfoCell.self, forCellReuseIdentifier: YHCertificateInfoCell.cellReuseIdentifier)
        tableView.backgroundView = emptyDataTipsView
        return tableView
    }()
    
    lazy var emptyDataTipsView:UIView = {
        let view = UIView(frame: CGRect(x: 0, y: 0, width: KScreenWidth, height: 124))
        view.isHidden = false
        
        let imgView = UIImageView(image: UIImage(named: "service_center_no_data"))
        imgView.contentMode = .scaleAspectFill
        view.addSubview(imgView)
        
        let label = UILabel()
        label.textColor = UIColor.labelTextColor2
        label.font = UIFont.PFSC_R(ofSize: 14)
        label.textAlignment = .center
        label.text = "没有找到相关资料哦~".local
        view.addSubview(label)
        
        imgView.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(130)
            make.width.height.equalTo(92)
            make.centerX.equalTo(view)
        }
        
        label.snp.makeConstraints { make in
            make.top.equalTo(imgView.snp.bottom).offset(12)
            make.centerX.equalTo(view)
        }
        return view
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.view.backgroundColor = .white
        self.gk_navigationBar.isHidden = true
        createUI()
        requestList(status: status)
    }
    
    func createUI() {
        view.addSubview(tableView)
        tableView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.height.equalTo(KScreenHeight - k_Height_NavigationtBarAndStatuBar - YHMaterialListViewController.segmentHeight)
        }
    }
}

extension YHCertificateResourceUploadVC: UITableViewDelegate, UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return items.count
    }

    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let cell = tableView.dequeueReusableCell(withIdentifier: YHCertificateInfoCell.cellReuseIdentifier, for: indexPath) as! YHCertificateInfoCell
        
        if 0 <= indexPath.section && indexPath.section < items.count {
            let item = items[indexPath.section]
            cell.updateModel(item)
            cell.templateBlock = {
                [weak self] in
                guard let self = self else { return }
                let view = YHCertificateTemplateView.templateView(item.templateInfo)
                view.scanTemplateBlock = {
                    [weak self] temlateInfo in
                    guard let self = self else { return }
                    let vc = UIViewController()
                    self.navigationController?.pushViewController(vc)
                }
                view.show()
            }
        }
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return UITableView.automaticDimension
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        
        let vc = YHUploadContentVC()
        vc.orderId = orderId
        vc.categoryInfo = categoryInfo
        if 0 <= indexPath.section && indexPath.section < items.count {
            let item = items[indexPath.section]
            vc.uploadInfo = item
        }
        self.navigationController?.pushViewController(vc)
    }

    private func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> CGFloat {
        return 14.0
    }
    
    private func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> CGFloat {
        return 1.0
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        
        return UIView()
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        
        return UIView()
    }
}

// MARK: - JXSegmentedListContainerViewListDelegate
extension YHCertificateResourceUploadVC: JXSegmentedListContainerViewListDelegate {
    func listView() -> UIView {
        return view
    }
}

extension YHCertificateResourceUploadVC {
    
    func requestList(status: YHCertificateUploadStatus, extra:[String:Any] = [:]) {
        
        /*
        // 状态
        "status_all": "",
        // 类型
        "template_cate_id": "",
        // 搜索
        "keywork": "",
         */
        
        var params:[String:Any] = [
                                    "order_id" : orderId ?? 0,
                                    "node": "1",
                                    "state": "1",
                                    "category_id": categoryInfo.categoryId,
                                    "supplement_ids": []]
        if !extra.isEmpty {
           params += extra
        }
        
        print(params)
        // state: 3:待上传 2:已驳回 1:已通过 0:审核中
        viewModel.getCertificateList(params: params) {
            
            [weak self] listInfo, error in
            guard let self = self else { return }
            
            items.removeAll()
            if let listInfo = listInfo {
                let arr = listInfo.supplementList
                var results: [YHSupplementInfo] = []
                if status == .all {
                    results.append(contentsOf:arr)
                } else {
                    for item in arr {
                        if item.checkStatus == status.rawValue {
                            results.append(item)
                        }
                    }
                }
                items.append(contentsOf: results)
            }
            emptyDataTipsView.isHidden = items.count > 0
            self.tableView.reloadData()
            
            if let errorMsg = error?.errorMsg, errorMsg.count > 0 {
                YHHUD.flash(message: errorMsg, duration:3)
            }
        }
    }
}
