//
//  YHUploadContentVC.swift
//  galaxy
//
//  Created by edy on 2024/3/12.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import IQKeyboardManagerSwift

class YHUploadContentVC: YHBaseViewController {

    var orderId : Int!
    var categoryInfo: YHCategoryData!
    var uploadInfo: YHSupplementInfo!
    var viewModel: YHCertificateViewModel = YHCertificateViewModel()
    var items:[YHContentUrl] = []
    var selectEditItem: YHContentUrl?

    var renameInputView: YHFileRenameInputView = {
        let view = YHFileRenameInputView.inputView(defalutText: "请输入名称")
        return view
    }()

    lazy var blackMaskView: UIView = {
        let view = UIView(frame:UIScreen.main.bounds)
        view.backgroundColor = UIColor(hex: 0x0F1214, alpha: 0.5)
        let tap = UITapGestureRecognizer(target: self, action: #selector(dismissed))
        view.addGestureRecognizer(tap)
        view.isHidden = true
        return view
    }()
    
    lazy var tableView: UITableView = {
        
        let tableView = UITableView(frame:.zero, style:.grouped)

        if #available(iOS 11.0, *) {
            tableView.contentInsetAdjustmentBehavior = .never
        }
        tableView.showsVerticalScrollIndicator = false
        tableView.estimatedSectionHeaderHeight = 1.0
        tableView.estimatedSectionFooterHeight = 1.0
        tableView.backgroundColor = .white
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "UITableViewCell")
        tableView.register(YHCertificateNameCell.self, forCellReuseIdentifier: YHCertificateNameCell.cellReuseIdentifier)
        tableView.register(YHCertificateTemplateCell.self, forCellReuseIdentifier: YHCertificateTemplateCell.cellReuseIdentifier)


        return tableView
    }()
    
    lazy var uploadBtn:UIButton = {
        let btn = UIButton()
        btn.setTitle("继续上传".local, for: .normal)
        btn.titleLabel?.font = UIFont.PFSC_M(ofSize: 16)
        btn.setTitleColor(.white, for: .normal)
        btn.backgroundColor = UIColor(hexString:"#4388FF")
        btn.layer.cornerRadius = 6.0
        btn.addTarget(self, action: #selector(didClickUploadBtn), for: .touchUpInside)
        return btn
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        self.view.backgroundColor = .white
        self.gk_navTitle = "上传内容"
        
        addKeyBoardNotify()
        createUI()
        
        items.removeAll()
        items.append(contentsOf: uploadInfo.contentUrl)
        tableView.reloadData()
        
        requestList()
        
        renameInputView.editBlock = {
            [weak self] text in
            guard let self = self else { return }
            if let selectEditItem = selectEditItem, let text = text {
                self.updateCertificateItem(selectEditItem, operation: "rename", rename: text)
            }
        }
    }
    
    deinit {
        removeNotify()
    }
    
    @objc func didClickUploadBtn() {
       let sheetView = YHCertificateUploadSheetView.sheetView
        sheetView.uploadFilesBlock = {
            [weak self] fileUrl in
            guard let self = self else { return }
            print(fileUrl)
            if let fileData = try? Data(contentsOf: fileUrl) {
                // 将文件数据上传到服务器
                let size = String(format: "%.2fM", Double(fileData.count)/(1024.0 * 1024.0))
                print("\(size)")
                self.viewModel.uploadFile(fileUrl.absoluteString) {[weak self] success, error in
                    guard let self = self else { return }

                }
            }
        }
        sheetView.uploadImageBlock = {
            [weak self] image in
            guard let self = self else { return }
            uploadImage(image)
        }
        sheetView.show()
    }
    
    func createUI() {

        view.addSubview(uploadBtn)
        view.addSubview(tableView)
        view.addSubview(blackMaskView)
        view.addSubview(renameInputView)
        tableView.snp.makeConstraints { make in
            make.top.equalTo(k_Height_NavigationtBarAndStatuBar)
            make.left.right.equalTo(view)
            if uploadInfo.checkStatus == YHCertificateUploadStatus.finish.rawValue {
                make.bottom.equalToSuperview()
            } else {
                make.bottom.equalTo(uploadBtn.snp.top).offset(-34)
            }
        }
        uploadBtn.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.right.equalToSuperview().offset(-16)
            make.height.equalTo(48.0)
            make.bottom.equalToSuperview().offset(-8-k_Height_safeAreaInsetsBottom())
        }

        renameInputView.snp.makeConstraints { make in
            make.left.right.equalTo(view)
            make.height.equalTo(YHFileRenameInputView.height)
            make.bottom.equalToSuperview().offset(YHFileRenameInputView.height)
        }
    }
}

extension YHUploadContentVC: UITableViewDelegate, UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 2
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if section == 0 {
            return 1
        }
        return items.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        if indexPath.section == 0 {
            
            let cell = tableView.dequeueReusableCell(withIdentifier: YHCertificateTemplateCell.cellReuseIdentifier, for: indexPath) as! YHCertificateTemplateCell
            cell.templateInfo = uploadInfo.templateInfo
            cell.templateClick = {
                [weak self] in
                guard let self = self else { return }
                // 查看模版 uploadInfo.templateInfo
                
            }
            return cell
        }
        
        let cell = tableView.dequeueReusableCell(withIdentifier: YHCertificateNameCell.cellReuseIdentifier, for: indexPath) as! YHCertificateNameCell
        if 0 <= indexPath.row && indexPath.row < items.count {
            let item = items[indexPath.row]
            cell.updateModel(item)
            cell.editBlock = {
                
                [weak self] contentItem in
                guard let self = self else { return }
                selectEditItem = contentItem
                let items = [YHCertificateEditItem(type:.rename, title:"重命名"),
                             YHCertificateEditItem(type:.preview, title:"预览"),
                             YHCertificateEditItem(type:.delete, title:"删除"),
                             YHCertificateEditItem(type:.cancel, title:"取消")]
                YHCertificateEditSheetView.sheetView(items:items) {
                    [weak self] editType in
                    guard let self = self else { return }
                    print("editType:\(editType.rawValue)")
                    
                    if editType == .rename { // 重命名
                        IQKeyboardManager.shared.enable = false
                        renameInputView.textField.text = contentItem.name
                        renameInputView.textField.becomeFirstResponder()
                        
                    } else if editType == .delete { // 删除
                        self.updateCertificateItem(contentItem, operation: "del", rename: "")
                        
                    } else if editType == .preview { // 预览
                       // 预览 contentItem
                    }
                }.show()
            }
        }
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        if indexPath.section == 0 {
            if uploadInfo.templateInfo.isNeedShowTemplate() {
                return UITableView.automaticDimension
            }
            return 0.0
        }
        return 55.0
    }
    
    private func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> CGFloat {
        if section == 0 {
            return 1.0
        }
        return UITableView.automaticDimension
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        
        let view = UIView()
        if section == 0 {
            return view
        }

        let titlelabel = UILabel()
        titlelabel.textColor = UIColor.mainTextColor
        titlelabel.textAlignment = .left
        titlelabel.font = UIFont.PFSC_M(ofSize:17)
        titlelabel.text = uploadInfo.name
        titlelabel.numberOfLines = 0
        view.addSubview(titlelabel)
        
        let statusLabel = UILabel()
        statusLabel.textColor = .warnColor
        statusLabel.backgroundColor = .warnColor8
        statusLabel.textAlignment = .center
        statusLabel.font = UIFont.PFSC_M(ofSize:10)
        statusLabel.text = uploadInfo.getStatusName()
        view.addSubview(statusLabel)
        
        let tipsLabel = UILabel()
        tipsLabel.textColor = .warnColor
        tipsLabel.font = UIFont.PFSC_R(ofSize:12)
        tipsLabel.textAlignment = .left
        tipsLabel.numberOfLines = 0
        tipsLabel.text = uploadInfo.auditContent
        view.addSubview(tipsLabel)
        
        titlelabel.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.top.equalToSuperview()
        }
        
        statusLabel.snp.makeConstraints { make in
            make.centerY.equalTo(titlelabel)
            make.left.equalTo(titlelabel.snp.right).offset(4)
            make.right.lessThanOrEqualTo(view).offset(-20)
            make.height.equalTo(16)
            make.width.equalTo(38)
        }
        
        tipsLabel.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalToSuperview().offset(-20)
            make.top.equalTo(titlelabel.snp.bottom).offset(3)
            make.bottom.equalToSuperview().offset(-15)
        }
        return view
    }
    
    private func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> CGFloat {
        if section == 0 {
            return 1.0
        }
        return 60.0
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        
        let view = UIView()
        if section == 0 {
            return view
        }
        
        let label = UILabel(frame: CGRect(x: 0, y: 20, width:KScreenWidth, height:20))
        label.textColor = UIColor.labelTextColor2
        label.textAlignment = .center
        label.font = UIFont.PFSC_R(ofSize:12)
        label.text = "*最多上传5/99张图片或文件"
        view.addSubview(label)
        
        return view
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        
    }
    
    @objc func dismissed() {
        renameInputView.textField.resignFirstResponder()
    }
}

extension YHUploadContentVC {
    
    func addKeyBoardNotify() {
        
        NotificationCenter.default.addObserver(self, selector: #selector(handleKeyboardNotification), name: UIResponder.keyboardWillShowNotification, object: nil)
        NotificationCenter.default.addObserver(self, selector: #selector(handleKeyboardNotification), name: UIResponder.keyboardWillHideNotification, object: nil)
    }
    
    func removeNotify() {
        NotificationCenter.default.removeObserver(self)
    }
    
    @objc func handleKeyboardNotification(_ notification: Notification) {
        
        if let userInfo = notification.userInfo {
            
            guard let keyboardFrame = (notification.userInfo?[UIResponder.keyboardFrameEndUserInfoKey] as AnyObject).cgRectValue else {return }

            let isKeyboardShow = notification.name == UIResponder.keyboardWillShowNotification
            self.blackMaskView.isHidden = !isKeyboardShow
            let bottomMargin = (isKeyboardShow ? -keyboardFrame.height : YHFileRenameInputView.height)
            
            if !isKeyboardShow {
                IQKeyboardManager.shared.enable = true
            }
            
            self.renameInputView.snp.updateConstraints { make in
                make.bottom.equalToSuperview().offset(bottomMargin)
            }
            self.view.setNeedsLayout()
            self.view.layoutIfNeeded()
        }
    }
}

extension YHUploadContentVC {
    
    func requestList() {
        
        let params:[String:Any] = [
                                    "order_id" : orderId ?? 0,
                                    "node": "1",
                                    "state": "1",
                                    "category_id": categoryInfo.categoryId,
                                    "supplement_ids": uploadInfo.id]

        print(params)
        viewModel.getCertificateList(params: params) {
            
            [weak self] listInfo, error in
            guard let self = self else { return }
            
            items.removeAll()
            if let listInfo = listInfo {
                categoryInfo = listInfo.categoryData
                let arr = listInfo.supplementList
                for item in arr {
                    items.append(contentsOf: item.contentUrl)
                }
            }
            self.tableView.reloadData()
            
            if let errorMsg = error?.errorMsg, errorMsg.count > 0 {
                YHHUD.flash(message: errorMsg, duration:3)
            }
        }
    }

    // 更改证件
    // operation参数必填，必须是：add(上传)、del（删除）、rename（重命名）
    func updateCertificateItem(_ model: YHContentUrl, operation:String, rename:String) {
        
        var name = model.name
        if operation == "rename" {
            name = rename
        }
        let dic:[String : Any] = [
                "id" : uploadInfo.id,
                "content_url": [
                    "name": name,
                    "url": model.url,
                    "suffix": model.suffix]]
        let params: [String: Any] = [
            "file_info" : [dic],
            "operation" : operation,
        ]
        self.viewModel.updateCertificates(params: params) {
            
            [weak self] success, error in
            guard let self = self else { return }
            
            if operation == "del" {
                if success {
                    YHHUD.flash(message: "删除成功")
                } else {
                    var msg = "删除失败"
                    if let errorMsg = error?.errorMsg, !errorMsg.isEmpty {
                        msg = errorMsg
                    }
                    YHHUD.flash(message:msg)
                }
                requestList()
                return
            }
                 
           if operation == "rename" {

                if success {
                    YHHUD.flash(message: "重命名成功")
                } else {
                    var msg = "重命名失败"
                    if let errorMsg = error?.errorMsg, !errorMsg.isEmpty {
                        msg = errorMsg
                    }
                    YHHUD.flash(message:msg)
                }
                requestList()
                return
            }
            
            if operation == "add" {
                if success {
                    YHHUD.flash(message: "添加成功")
                } else {
                    var msg = "添加失败"
                    if let errorMsg = error?.errorMsg, !errorMsg.isEmpty {
                        msg = errorMsg
                    }
                    YHHUD.flash(message:msg)
                }
                requestList()
                return
            }
        }
    }
    
    func uploadImage(_ img: UIImage) {
        
        // 先OSS上传得到URL
        YHHUD.show(.progress(message: "上传中..."))
        self.viewModel.uploadImage(img) {
            [weak self] url, error in
            guard let self = self else { return }
            YHHUD.hide()
            if let url = url, !url.isEmpty {
                let imgName = url.lastPathComponent
                var suffix = "jpg"
                let suffixName = url.pathExtension.lowercased()
                if !suffixName.isEmpty {
                    suffix = suffixName
                }
                
                // 再调用业务接口
                let model = YHContentUrl()
                model.name = imgName
                model.url = url
                model.suffix = suffix
                updateCertificateItem(model, operation: "add", rename: "")
                return
            }
            //
            var msg = "上传图片失败"
            if let errorMsg = error?.errorMsg, !errorMsg.isEmpty {
                msg = errorMsg
            }
            YHHUD.flash(message: msg)
        }
    }    
}

