//
//  YHCertificateInfoCell.swift
//  galaxy
//
//  Created by edy on 2024/3/13.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import AttributedString


class YHCertificateInfoCell: UITableViewCell {

    
    static let cellReuseIdentifier = "YHCertificateNameCell"
    
    var status : YHCertificateUploadStatus = .preUpload
    var templateBlock:(()->())?
    var whiteView: UIView!
    var nameTextView: UITextView!
    var infoLabel: UILabel!
    var statusBtn: UIButton!
    
    private lazy var templateLabel : UILabel = {
        let label = UILabel(frame: CGRect(x: 0, y: 0, width: 48, height: 16))
        label.text = "资料模版"
        label.font = .PFSC_M(ofSize: 10)
        label.backgroundColor = .brandMainColor8
        label.textColor = .brandMainColor
        label.layer.cornerRadius = 3
        label.clipsToBounds = true
        label.textAlignment = .center
        label.isUserInteractionEnabled = true
        let tap = UITapGestureRecognizer(target: self, action: #selector(didTemplateBtnClicked))
        label.addGestureRecognizer(tap)
        return label
    }()
    

    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        setupUI()
    }
    
    func updateModel(_ model: YHSupplementInfo) {
        
        if let status = YHCertificateUploadStatus(rawValue: model.checkStatus) {
            
            var titleColor: UIColor = .labelTextColor2
            var title = ""
            switch status  {
            case .preUpload:
                titleColor = .brandMainColor
                title = "待上传".local
            case .rejected:
                titleColor = .failColor
                title = "已驳回".local
            case .review:
                titleColor = .labelTextColor2
                title = "审核中".local
            case .finish:
                titleColor = .labelTextColor2
                title = "已通过".local
            case .all:
                titleColor = .labelTextColor2
            }
            statusBtn.setTitleColor(titleColor, for:.normal)
            statusBtn.setTitle(title, for: .normal)
        }
        
        if model.templateInfo.materialPath.isEmpty && model.templateInfo.description.isEmpty {
            
            nameTextView.attributed.text = """
            \(model.name, .foreground(UIColor.mainTextColor), .font(UIFont.PFSC_M(ofSize: 16)))
            """
            
        } else {
            nameTextView.attributed.text = """
            \(model.name, .foreground(UIColor.mainTextColor), .font(UIFont.PFSC_M(ofSize: 16)))  \(.view(templateLabel, .original(.center)))
            """
        }
        infoLabel.text = "类型: \(model.typeName) 所属人: \(model.nameExtra.userName)"
    }
    
    @objc func didTemplateBtnClicked() {
        if let templateBlock = templateBlock {
            templateBlock()
        }
    }
    
    func setupUI() {
        
        self.selectionStyle = .none
        contentView.backgroundColor = UIColor(hexString:"#F8F8F8")
        
        whiteView = UIView()
        whiteView.layer.cornerRadius = 6.0
        whiteView.clipsToBounds = true
        whiteView.backgroundColor = .white
        contentView.addSubview(whiteView)
        
        nameTextView = UITextView()
        nameTextView.textColor = UIColor.mainTextColor
        nameTextView.font = UIFont.PFSC_M(ofSize: 16)
        nameTextView.isScrollEnabled = false
        nameTextView.isEditable = false
        nameTextView.isSelectable = false
        whiteView.addSubview(nameTextView)
        
        nameTextView.attributed.text = """
        \("我是资料名称", .foreground(UIColor.mainTextColor), .font(UIFont.PFSC_M(ofSize: 16)))  \(.view(templateLabel, .original(.center)))
        """
        
        infoLabel = UILabel()
        infoLabel.textColor = UIColor.labelTextColor2
        infoLabel.textAlignment = .left
        infoLabel.font = UIFont.PFSC_R(ofSize:11)
        infoLabel.text = "类型：证件资料   所属人：张康"
        whiteView.addSubview(infoLabel)
        
        statusBtn = UIButton()
        statusBtn.titleLabel?.font = UIFont.PFSC_R(ofSize:14)
        
        let iconWidth = 16.0
        let titleWidth = 42.0
        statusBtn.titleEdgeInsets = UIEdgeInsets(top: 0, left: -iconWidth, bottom: 0, right: iconWidth)
        statusBtn.imageEdgeInsets = UIEdgeInsets(top: 0, left: titleWidth, bottom: 0, right: -titleWidth)
        statusBtn.setImage(UIImage(named:"my_cer_arrow_right"), for:.normal)
        statusBtn.setTitleColor(.labelTextColor2, for:.normal)
        whiteView.addSubview(statusBtn)
        
        whiteView.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalToSuperview().offset(-20)
            make.top.bottom.equalToSuperview()
        }
        
        nameTextView.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(10)
            make.top.equalToSuperview().offset(4)
            make.right.equalTo(statusBtn.snp.left)
        }
        
        infoLabel.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.right.equalTo(nameTextView)
            make.top.equalTo(nameTextView.snp.bottom)
            make.bottom.equalToSuperview().offset(-12)
            make.height.equalTo(20)
        }
        
        statusBtn.snp.makeConstraints { make in
            make.height.equalTo(60)
            make.width.equalTo(92)
            make.centerY.equalToSuperview()
            make.right.equalToSuperview()
        }
    }

}
