//
//  YHCertificateTemplateCell.swift
//  galaxy
//
//  Created by edy on 2024/3/19.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHCertificateTemplateCell: UITableViewCell {

    static let cellReuseIdentifier = "YHCertificateTemplateCell"
    
    var templateClick:(()->())?
    
    var templateInfo: YHTemplateInfo? {
        didSet {
            guard let templateInfo = templateInfo else {
                contentView.isHidden = true
                return
            }
            
            if templateInfo.description.isEmpty && templateInfo.materialPath.isEmpty {
                contentView.isHidden = true
                return
            }
            
            contentView.isHidden = false
            
            if !templateInfo.name.isEmpty {
                templateTitleLabel.text = "\(templateInfo.name)示例模版"
            } else {
                templateTitleLabel.text = ""
            }
            if !templateInfo.description.isEmpty {
                tipsLabel.text = "注意事项: \(templateInfo.description)"
            } else {
                tipsLabel.text = ""
            }
            let noTemplate = templateInfo.materialPath.isEmpty
            templateView.isHidden = noTemplate
            templateView.snp.updateConstraints { make in
                make.height.equalTo(noTemplate ? 0.0 : 62.0)
                make.bottom.equalToSuperview().offset(noTemplate ? 0.0 : -34.0)
            }
            self.setNeedsLayout()
            self.layoutIfNeeded()
        }
    }
    lazy var tipsLabel: UILabel = {
        let label = UILabel()
        label.textColor = UIColor.labelTextColor2
        label.textAlignment = .left
        label.font = UIFont.PFSC_R(ofSize:12)
        label.numberOfLines = 0
        return label
    }()
    
    lazy var templateTitleLabel: UILabel = {
        let label = UILabel()
        label.textColor = UIColor.mainTextColor
        label.textAlignment = .left
        label.font = UIFont.PFSC_M(ofSize:17)
        label.text = "示例模版"
        label.numberOfLines = 0
        return label
    }()
    
    lazy var templateView: YHCertificateSampleTemplateView = {
        let view = YHCertificateSampleTemplateView(frame:CGRectZero)
        let tap = UITapGestureRecognizer(target:self, action:#selector(didTemplateTap))
        view.addGestureRecognizer(tap)
        return view
    }()
    
    @objc func didTemplateTap() {
        if let templateClick = templateClick {
            templateClick()
        }
    }

    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        createUI()
    }
    
    func createUI() {
    
        self.selectionStyle = .none
        
        contentView.addSubview(templateTitleLabel)
        contentView.addSubview(tipsLabel)
        contentView.addSubview(templateView)
        
        templateTitleLabel.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalToSuperview().offset(-20)
            make.top.equalToSuperview().offset(16)
        }
        tipsLabel.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalToSuperview().offset(-20)
            make.top.equalTo(templateTitleLabel.snp.bottom).offset(5)
        }
        templateView.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalToSuperview().offset(-20)
            make.top.equalTo(tipsLabel.snp.bottom).offset(15)
            make.height.equalTo(62.0)
            make.bottom.equalToSuperview().offset(-34)
        }
    }

}
