//
//  YHCertificateTemplateView.swift
//  galaxy
//
//  Created by edy on 2024/3/20.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//
/*
 【Usage】
 let view = YHCertificateTemplateView.templateView(templateInfo)
 view.scanTemplateBlock = {
     [weak self] temlateInfo in
     guard let self = self else { return }
 }
 view.show()
 */

import UIKit

class YHCertificateTemplateView: UIView {

    static func templateView(_ model: YHTemplateInfo) -> YHCertificateTemplateView  {
        let sheetView = YHCertificateTemplateView(frame:UIScreen.main.bounds)
        sheetView.updateModel(model)
        return sheetView
    }

    var templateInfo: YHTemplateInfo?
    var scanTemplateBlock: ((YHTemplateInfo?)->())?
    
    lazy var blackMaskView: UIView = {
        let view = UIView()
        view.backgroundColor = UIColor(hex: 0x0F1214, alpha: 0.5)
        let tap = UITapGestureRecognizer(target: self, action: #selector(dismiss))
        view.addGestureRecognizer(tap)
        return view
    }()
    
    lazy var whiteContentView: UIView = {
        let view = UIView()
        view.backgroundColor = .white
        return view
    }()
    
    lazy var topView:UIView = {
        let view = UIView()
        view.addSubview(titleLabel)
        view.addSubview(closeBtn)
        
        let line = UIView()
        line.backgroundColor = .separatorColor
        view.addSubview(line)
        
        titleLabel.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(16)
            make.left.equalToSuperview().offset(64)
            make.right.equalToSuperview().offset(-64)
            make.bottom.equalToSuperview().offset(-12)
        }
        closeBtn.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(16)
            make.right.equalToSuperview().offset(-20)
            make.width.height.equalTo(24)
        }
        closeBtn.YH_clickEdgeInsets = UIEdgeInsets(top: 15, left: 15, bottom: 15, right: 15)
        line.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalToSuperview().offset(-20)
            make.height.equalTo(1)
            make.bottom.equalToSuperview()
        }
        return view
    }()
    
    lazy var scrollView: UIScrollView = {
        let view = UIScrollView()
        view.addSubview(scrollContentView)
        scrollContentView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        return view
    }()
    
    lazy var scrollContentView: UIView = {
        let view = UIView()
        return view
    }()
    
    lazy var titleLabel: UILabel = {
        let label = UILabel()
        label.textColor = UIColor.mainTextColor
        label.textAlignment = .center
        label.font = UIFont.PFSC_B(ofSize:17)
        label.numberOfLines = 0
        label.text = "示例模版"
        return label
    }()
    
    lazy var closeBtn: UIButton = {
        let btn = UIButton()
        btn.setImage(UIImage(named:"my_cer_sheet_close"), for: .normal)
        btn.addTarget(self, action: #selector(dismiss), for: .touchUpInside)
        return btn
    }()
    
    lazy var tipsLabel: UILabel = {
        let label = UILabel()
        label.textColor = UIColor.mainTextColor
        label.textAlignment = .left
        label.font = UIFont.PFSC_R(ofSize:14)
        label.numberOfLines = 0
        label.text = ""
        return label
    }()
    
    lazy var templateView: YHCertificateSampleTemplateView = {
        let view = YHCertificateSampleTemplateView(frame:CGRectZero)
        view.tag = YHCertificateUploadType.sample.rawValue
        let tap = UITapGestureRecognizer(target:self, action:#selector(didTemplateViewClicked))
        view.addGestureRecognizer(tap)
        return view
    }()
    
    lazy var knowBtn:UIButton = {
        let btn = UIButton()
        btn.setTitle("知道了".local, for: .normal)
        btn.titleLabel?.font = UIFont.PFSC_M(ofSize: 16)
        btn.setTitleColor(.white, for: .normal)
        btn.backgroundColor = UIColor(hexString:"#4388FF")
        btn.layer.cornerRadius = 8.0
        btn.addTarget(self, action: #selector(didClickKnownBtn), for: .touchUpInside)
        return btn
    }()
    
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        createUI()
    }
    
    func updateModel(_ model: YHTemplateInfo) {
        
        templateInfo = model
        if !model.name.isEmpty {
            titleLabel.text = "\(model.name)示例模版"
        }
        
        if !model.description.isEmpty {
            tipsLabel.text = "注意事项:\(model.description)"
        }
        templateView.isHidden =  model.materialPath.isEmpty
    
        let topMargin = model.description.isEmpty ? 0 : 20
        templateView.snp.updateConstraints { make in
            make.top.equalTo(tipsLabel.snp.bottom).offset(topMargin)
        }
        self.setNeedsLayout()
        self.layoutIfNeeded()
    }
    
    func createUI() {
        
        self.addSubview(blackMaskView)
        self.addSubview(whiteContentView)
        whiteContentView.addSubview(topView)
        whiteContentView.addSubview(scrollView)
        whiteContentView.addSubview(knowBtn)

        scrollContentView.addSubview(tipsLabel)
        scrollContentView.addSubview(templateView)
        
        let corner = UIRectCorner(rawValue: UIRectCorner.topLeft.rawValue | UIRectCorner.topRight.rawValue)
        let path = UIBezierPath(roundedRect:bounds,byRoundingCorners: corner,cornerRadii:CGSizeMake(16.0, 16.0));
        let layer = CAShapeLayer();
        layer.frame = whiteContentView.bounds;
        layer.path = path.cgPath;
        whiteContentView.layer.mask = layer;
        
        blackMaskView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
        whiteContentView.snp.makeConstraints { make in
            make.left.right.bottom.equalToSuperview()
            make.height.equalTo(484)
        }
        topView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
        }
        
        scrollView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalTo(topView.snp.bottom).offset(20)
            make.bottom.equalTo(knowBtn.snp.top).offset(-8)
        }
        
        tipsLabel.snp.makeConstraints { make in
            let gap = 20.0
            make.left.equalToSuperview().offset(gap)
            make.right.equalToSuperview().offset(-gap)
            make.width.equalTo(KScreenWidth-gap*2.0)
            make.top.equalToSuperview()
        }
        
        templateView.snp.makeConstraints { make in
            let gap = 20.0
            make.left.equalToSuperview().offset(gap)
            make.right.equalToSuperview().offset(-gap)
            make.width.equalTo(KScreenWidth-gap*2.0)
            make.height.equalTo(62.0)
            make.top.equalTo(tipsLabel.snp.bottom).offset(20)
            make.bottom.equalToSuperview().offset(-20)
        }

        knowBtn.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.right.equalToSuperview().offset(-16)
            make.height.equalTo(48.0)
            make.bottom.equalToSuperview().offset(-8-k_Height_safeAreaInsetsBottom())
        }
    }
    
    func show() -> YHCertificateTemplateView {
        UIApplication.shared.yhKeyWindow()?.addSubview(self)
        return self
    }
    
    @objc func dismiss() {
        self.removeFromSuperview()
    }
    
    @objc func didTemplateViewClicked() {
        if let scanTemplateBlock = scanTemplateBlock {
            scanTemplateBlock(templateInfo)
        }
        dismiss()
    }
    
    @objc func didClickKnownBtn() {
        dismiss()
    }
}
